@@ -1,5 +1,6 @@
 import os
 import logging 
+import platform
 
 g_directory_stack = []
 
@@ -24,6 +25,12 @@ def create_directory_if_not_exists(path, level=logging.DEBUG):
         logger.debug(path, " does not exist, creating ...")
         os.makedirs(path) 
 
+def get_cache_directory():
+    if platform.system().lower() == "windows":
+        return os.path.expandvars(%localappdata%)
+    else:
+        return "~/.cache"
+
 def get_git_directory(level=logging.DEBUG):
     logger = logging.getLogger("logger")
     logger.setLevel(level)
